﻿/*
Licensed under the MIT License

Copyright (c) 2011 Rasmus Wriedt Larsen
www.rasmuswriedtlarsen.com

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package com.rasmuswriedtlarsen.utils 
{
	import flash.utils.getQualifiedClassName;
	
	public class ArrayTracer
	{
		/**
		 * Trace an array so it looks nice!
		 * @param	array	The Array to trace.
		 * @param	isOutputOfClassNamesFullyQualified	Should output of classes be 'Package.Class' (true) or 'Class' (false).
		 */
		public static function traceArray ( array:Array, isOutputOfClassNamesFullyQualified:Boolean = true ) :void
		{
			trace ( getArrayString ( array , isOutputOfClassNamesFullyQualified ) ) ;
		}
		
		/**
		 * Get the string for tracing an array so it looks nice!
		 * @param	array	The Array to trace.
		 * @param	isOutputOfClassNamesFullyQualified	Should output of classes be 'Package.Class' (true) or 'Class' (false).
		 * @return A String containing the Array to trace.
		 */
		public static function getArrayString ( array:Array, isOutputOfClassNamesFullyQualified:Boolean = true ) :String
		{
			var traceString:String = "[ "
			for ( var i:int = 0; i < array.length; i++ )
			{
				var element:* = array[i] ;
				if ( element is Array )
				{
					traceString += getArrayString ( element ) ;
				}
				else if ( element is String )
				{
					traceString += '"' + String ( element ) + '"';
				}
				else if ( element is Class )
				{
					if( isOutputOfClassNamesFullyQualified ) 
					{
						traceString += getQualifiedClassName ( element ) .replace ( "::", "." ) ;
					}
					else
					{
						traceString += String ( element ).replace("[class ","").replace("]","") ;
					}
				}
				else
				{
					traceString += String ( element ) ;
				}
				
				if(i != array.length - 1) 
					traceString += ", "
			}
			
			traceString += " ]";
			return traceString;
		}
	}

}